@@ -107,15 +107,14 @@ class RosPkgLoader(RosdepLoader):
         """
         'Views' map to ROS stack names.
         """
-        return self._rosstack.list() + [DEFAULT_VIEW_KEY]
+        return list(self._rosstack.list()) + [DEFAULT_VIEW_KEY]
 
     def get_loadable_resources(self):
         """
         'Resources' map to ROS packages names.
         """
         if not self._loadable_resource_cache:
-            loadable_list = self._rospack.list()
-            self._loadable_resource_cache = loadable_list[:]
+            self._loadable_resource_cache = list(self._rospack.list())
         return self._loadable_resource_cache
 
     def get_rosdeps(self, resource_name, implicit=True):
